@@ -1,19 +1,4 @@
-#
-# This file is part of Freedom Maker.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: GPL-3.0-or-later
 """
 Worker class to build Vagrant images.
 """
@@ -47,6 +32,10 @@ class VagrantImageBuilder(VirtualBoxAmd64ImageBuilder):
 
     def vagrant_package(self, vm_file, vagrant_file):
         """Create a vagrant package from VM file."""
-        library.run(['bin/vagrant-package',
-                     '--distribution', self.arguments.distribution,
-                     '--output', vagrant_file, vm_file])
+        command = [
+            'bin/vagrant-package', '--distribution',
+            self.arguments.distribution, '--release-components'
+        ]
+        command.extend(self.release_components)
+        command += ['--output', vagrant_file, vm_file]
+        library.run(command)
