@@ -1,19 +1,4 @@
-#
-# This file is part of Freedom Maker.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# SPDX-License-Identifier: GPL-3.0-or-later
 """
 Tests for checking Freedom Maker's internal library of actions.
 """
@@ -318,9 +303,7 @@ modify x x
             self.state['mount_point'] + '/boot/firmware'
         ])
 
-        library.mount_filesystem(self.state,
-                                 '/dev/pts',
-                                 'dev/pts',
+        library.mount_filesystem(self.state, '/dev/pts', 'dev/pts',
                                  is_bind_mount=True)
         run.assert_called_with([
             'mount', '/dev/pts', self.state['mount_point'] + '/dev/pts', '-o',
@@ -437,33 +420,23 @@ modify x x
         ])
 
     @patch('freedommaker.library.run')
-    def test_qemu_debootstrap(self, run):
-        """Test debootstrapping using qemu."""
-        library.qemu_debootstrap(self.state, 'i386', 'stretch', 'minbase',
-                                 ['main', 'contrib'], ['p1', 'p2'],
-                                 'http://deb.debian.org/debian')
+    def test_debootstrap(self, run):
+        """Test debootstrapping."""
+        library.debootstrap(self.state, 'i386', 'stretch', 'minbase',
+                            ['main', 'contrib'], ['p1', 'p2'],
+                            'http://deb.debian.org/debian')
         run.assert_called_with([
-            'qemu-debootstrap', '--arch=i386', '--variant=minbase',
+            'debootstrap', '--arch=i386', '--variant=minbase',
             '--components=main,contrib', '--include=p1,p2', 'stretch',
             self.state['mount_point'], 'http://deb.debian.org/debian'
         ])
 
-        self.assertEqual(
-            self.state['cleanup'],
-            [[library.qemu_remove_binary, (self.state, ), {}],
-             [
-                 library.unmount_filesystem,
-                 (None, self.state['mount_point'] + '/etc/machine-id'), {
-                     'ignore_fail': True
-                 }
-             ]])
-
-    @patch('freedommaker.library.run')
-    def test_qemu_remove_binary(self, run):
-        """Test removing the qemu binary within the mount point."""
-        library.qemu_remove_binary(self.state)
-        run.assert_called_with(
-            ['rm', '-f', self.state['mount_point'] + '/usr/bin/qemu-*-static'])
+        self.assertEqual(self.state['cleanup'], [[
+            library.unmount_filesystem,
+            (None, self.state['mount_point'] + '/etc/machine-id'), {
+                'ignore_fail': True
+            }
+        ]])
 
     def test_no_daemon_policy(self):
         """Test that no daemon run policy is properly set."""
@@ -483,12 +456,22 @@ modify x x
         library.install_package(self.state, 'nmap')
         run.assert_called_with(self.state,
                                ['apt-get', 'install', '-y', 'nmap'])
-        library.install_package(self.state,
-                                'freedombox',
-                                install_from_backports=True)
-        run.assert_called_with(self.state, [
-            'find', '.', '-maxdepth', '1', '-iname', '"freedombox*.deb"',
-            '-delete'
+        run.reset_mock()
+
+    @patch('freedommaker.library.run_in_chroot')
+    def test_install_from_backports(self, run):
+        library.install_from_backports(
+            self.state,
+            ('freedombox', 'freedombox-doc-en', 'freedombox-doc-es'))
+
+        self.assertEqual(run.call_args_list, [
+            call(self.state, [
+                'apt-get', 'install', '-y',
+                f'freedombox/{library.STABLE_CODENAME}-backports',
+                f'freedombox-doc-en/{library.STABLE_CODENAME}-backports',
+                f'freedombox-doc-es/{library.STABLE_CODENAME}-backports'
+            ]),
+            call(self.state, ['apt-get', 'autoremove', '-y'])
         ])
 
     @patch('freedommaker.library.install_package')
@@ -497,11 +480,11 @@ modify x x
         """Test installing a custom package."""
         with tempfile.NamedTemporaryFile() as file_path:
             library.install_custom_package(self.state, file_path.name)
-            install_package.assert_called_with(self.state, 'gdebi-core')
 
-            run.assert_called_with(
-                self.state,
-                ['gdebi', '-n', '/tmp/' + os.path.basename(file_path.name)])
+            run.assert_called_with(self.state, [
+                'apt', 'install', '-y', '--allow-downgrades',
+                '/tmp/' + os.path.basename(file_path.name)
+            ])
 
     def test_set_hostname(self):
         """Test that hostname is properly set."""
@@ -524,7 +507,7 @@ ff02::2 ip6-allrouters
         self.assertEqual(options, 'errors=remount-ro')
 
         options = library.get_fstab_options('btrfs')
-        self.assertEqual(options, 'defaults')
+        self.assertEqual(options, 'compress=zstd:1')
 
     @patch('freedommaker.library.run', return_value=b'test-uuid')
     def test_get_uuid_of_device(self, run):
@@ -545,14 +528,11 @@ ff02::2 ip6-allrouters
         }
         self.state['sub_mount_points'] = {'root': None, 'boot': 'boot'}
 
-        expected_content = 'UUID=root-uuid / btrfs defaults 0 1\n'
+        expected_content = 'UUID=root-uuid / btrfs compress=zstd:1 0 1\n'
         get_uuid.return_value = 'root-uuid'
         with self.assert_file_change(fstab_path, 'initial-trash',
                                      expected_content):
-            library.add_fstab_entry(self.state,
-                                    'root',
-                                    'btrfs',
-                                    1,
+            library.add_fstab_entry(self.state, 'root', 'btrfs', 1,
                                     append=False)
 
         expected_content += 'UUID=boot-uuid /boot ext4 errors=remount-ro 0 2\n'
@@ -570,24 +550,42 @@ ff02::2 ip6-allrouters
             call(self.state, ['grub-install', '/dev/test/loop99'])
         ])
 
+        run.reset_mock()
+        library.install_grub(self.state, target='arm-efi')
+        self.assertEqual(run.call_args_list, [
+            call(self.state, ['update-grub']),
+            call(self.state,
+                 ['grub-install', '/dev/test/loop99', '--target=arm-efi'])
+        ])
+
+        run.reset_mock()
+        library.install_grub(self.state, target='arm-efi', is_efi=True)
+        self.assertEqual(run.call_args_list, [
+            call(self.state, ['update-grub']),
+            call(self.state, [
+                'grub-install', '/dev/test/loop99', '--target=arm-efi',
+                '--no-nvram'
+            ])
+        ])
+
     @patch('freedommaker.library.run_in_chroot')
     def test_setup_apt(self, run):
         """Test setting up apt."""
         sources_path = self.state['mount_point'] + '/etc/apt/sources.list'
 
         stable_content = '''
-deb http://deb.debian.org/debian stretch main
-deb-src http://deb.debian.org/debian stretch main
+deb http://deb.debian.org/debian stable main
+deb-src http://deb.debian.org/debian stable main
 
-deb http://deb.debian.org/debian stretch-updates main
-deb-src http://deb.debian.org/debian stretch-updates main
+deb http://deb.debian.org/debian stable-updates main
+deb-src http://deb.debian.org/debian stable-updates main
 
-deb http://security.debian.org/debian-security/ stretch/updates main
-deb-src http://security.debian.org/debian-security/ stretch/updates main
+deb http://security.debian.org/debian-security/ stable-security main
+deb-src http://security.debian.org/debian-security/ stable-security main
 '''
         with self.assert_file_change(sources_path, None, stable_content):
             library.setup_apt(self.state, 'http://deb.debian.org/debian',
-                              'stretch', ['main'])
+                              'stable', ['main'])
 
         self.assertEqual(run.call_args_list, [
             call(self.state, ['apt-get', 'update']),
